
##
## Supporting Information - R script for the manuscript paper entitled:
## "Systematic site selection for multi-species monitoring networks"
## Carvalho, S.[1], Gonalves, J.[1], Guisan, A.[2], Honrado, J.[1], 2015
## Journal Of Applied Ecology
## 
## [1] InBIO/CIBIO - Research Center in Biodiversity and Genetic Resources
## 	   Faculty of Sciences - University of Porto
## [2] University of Lausanne, Ecology and Evolution
## 
## Contacting author on this section: 
## Joo Gonalves (jfgoncalves[at]fc.up.pt / joaofgo[at]gmail.com)
##
## Script title: make biplots comparing cost and network performance indicators
##

library(vegan)
library(foreign)

load(file="D:/MyDocs/OptimMonitNetworks/optimSampCost_AllObjectsIndices.RData")

removeListValues<-function(x,remInd=c("T20","T40")){
  for(i in 1:length(x)){
    for(ind in remInd){
      x[[i]][[ind]]<-NULL
    }
  }
  
  return(x)
}

outDir<-"D:/MyDocs/OptimMonitNetworks"

## Survey effort cost ------------------------------------------------------

# Non-optimized
y.nonOptimSamp<-removeListValues(nonOptimSamp.Ind8)
y.nonOptimSamp<-unlist(y.nonOptimSamp)

# Optimized
y.optimSamp<-removeListValues(optimSamp.Ind8)
y.optimSamp<-unlist(y.optimSamp)

#cols<-c("grey90","grey65","grey45","grey25","grey5")
# Remove T20 and T40 values
cols<-c("grey90","grey45","grey5")
pos<-c("bottomright","bottomright","topright","topleft","topleft","topleft","bottomright")


for(i in 1:(length(Indices[[1]])-1)){ # Cost not included (last entry in list)

  # Index values
  x.optimSamp<-removeListValues(eval(parse(text=paste("optimSamp.Ind",i,sep=""))))
  x.optimSamp<-unlist(x.optimSamp)

  # Index values
  x.nonOptimSamp<-removeListValues(eval(parse(text=paste("nonOptimSamp.Ind",i,sep=""))))
  x.nonOptimSamp<-unlist(x.nonOptimSamp)
  
  x.r<-range(c(x.optimSamp,x.nonOptimSamp))
  y.r<-range(c(y.optimSamp,y.nonOptimSamp))
  
  x.lab<-Indices[[2]][i]
  fn<-Indices[[1]][i]
  
  png(width=2500,height=2500,res=300,file=paste(outDir,"/0",i,"_surveyEffortCost_",fn,".png",sep=""))
  
  plot(x.optimSamp,y.optimSamp,xlim=x.r,ylim=y.r,col=rep(cols,each=100,times=4)
       ,ylab="Total field survey effort (TFSE)",xlab=x.lab,pch=1,cex.lab=1.2,cex.axis=1.2,cex=1.4)
  
  #points(x.nonOptimSamp,y.nonOptimSamp,pch=rep(1:5,each=100,times=4),col=rep(c("grey85","grey60",
  #"grey40","grey20"),each=500),cex=0.8)
  points(x.nonOptimSamp,y.nonOptimSamp,pch=3,col=rep(cols,each=100,times=4),cex=1.4)
  
#   #legend("topright",legend=c("OPTM","NOPT"),lty=c(1,2),lwd=2,col="red",cex=0.7)
#   legend(pos[i],legend=c(paste("OPTM",paste("T",seq(10,50,by=10),sep=""),sep="-"),
#          paste("NOPT",paste("T",seq(10,50,by=10),sep=""),sep="-")),
#          col=rep(cols,2),pch=rep(c(1,3),each=5),cex=0.7)
  
  # Version with T20 and T40 removed
  legend(pos[i],legend=c(paste("OPTM",paste("T",seq(10,50,by=20),sep=""),sep="-"),
                         paste("NOPT",paste("T",seq(10,50,by=20),sep=""),sep="-")),
         col=rep(cols,2),pch=rep(c(1,3),each=3),cex=0.7)
  
  clip(x.r[1],x.r[2],y.r[1],y.r[2])
  
  abline(lm(y~x,data=data.frame(x=x.optimSamp,y=y.optimSamp)),col="red",lwd=2)
  abline(lm(y~x,data=data.frame(x=x.nonOptimSamp,y=y.nonOptimSamp)),col="red",lwd=2,lty=2)

  dev.off()
}
