
##
## Supporting Information - R script for the manuscript paper entitled:
## "Systematic site selection for multi-species monitoring networks"
## Carvalho, S.[1], Gonalves, J.[1], Guisan, A.[2], Honrado, J.[1], 2015
## Journal Of Applied Ecology
## 
## [1] InBIO/CIBIO - Research Center in Biodiversity and Genetic Resources
## 	   Faculty of Sciences - University of Porto
## [2] University of Lausanne, Ecology and Evolution
## 
## Contacting author on this section: 
## Joo Gonalves (jfgoncalves[at]fc.up.pt / joaofgo[at]gmail.com)
##
## Script title: make boxplots of Pi and Di for each IUCN status
##

library(readxl)

# Load data
load("D:/MyDocs/OptimMonitNetworks/MonintNetworkCompObjs.RData")
iucn<-read_excel("D:/MyDocs/OptimMonitNetworks/species_table.xlsx")
prev_diff<-apply(statsPerSp.PrevDiff,1,mean)
tmp<-data.frame(iucn,sp=names(prev_i),pi=prev_i,di=prev_diff)


png("D:/MyDocs/OptimMonitNetworks/IUCN_Status_vs_pi_Di_with-NE.png",height=2000,width=3500,res=300)
par(mfrow=c(1,2),mar=c(4,5,2,1))

# boxplot(pi~IUCN_ord,data=tmp[tmp[,"IUCN_ord"]>0,],xlab="IUCN status",ylab="Species predicted prevalence (Pi)",
#         axes=FALSE,cex=1.4,cex.lab=1.4,cex.axis=1.4,col="light grey")
boxplot(pi~IUCN_ord,data=tmp,xlab="IUCN status",ylab="Species predicted prevalence (Pi)",
        axes=FALSE,cex=1.4,cex.lab=1.4,cex.axis=1.4,col="light grey")
abline(h=0,lty=2,col="grey")
#axis(side=1,at=1:3,label=c("LC","NT","VU"),cex.axis=1.4)
axis(side=1,at=1:4,label=c("NE","LC","NT","VU"),cex.axis=1.4)
axis(side=2,at=seq(0,1,0.2),cex.axis=1.4)
box()

## ------ ##
# 
# boxplot(di~IUCN_ord,data=tmp[tmp[,"IUCN_ord"]>0,],xlab="IUCN status",ylab="Difference in monitoring prevalence (Di)",
#         axes=FALSE,cex=1.4,cex.lab=1.4,cex.axis=1.4,col="light grey")
boxplot(di~IUCN_ord,data=tmp,xlab="IUCN status",ylab="Difference in monitoring prevalence (Di)",
        axes=FALSE,cex=1.4,cex.lab=1.4,cex.axis=1.4,col="light grey")
abline(h=0,lty=2,col="grey")
#axis(side=1,at=1:3,label=c("LC","NT","VU"),cex.axis=1.4)
axis(side=1,at=1:4,label=c("NE","LC","NT","VU"),cex.axis=1.4)
axis(side=2,at=seq(-0.25,0.3,0.1),cex.axis=1.4)
box()

dev.off()



