
##
## Supporting Information - R script for the manuscript paper entitled:
## "Systematic site selection for multi-species monitoring networks"
## Carvalho, S.[1], Gonalves, J.[1], Guisan, A.[2], Honrado, J.[1], 2015
## Journal Of Applied Ecology
## 
## [1] InBIO/CIBIO - Research Center in Biodiversity and Genetic Resources
## 	   Faculty of Sciences - University of Porto
## [2] University of Lausanne, Ecology and Evolution
## 
## Contacting author on this section: 
## Joo Gonalves (jfgoncalves[at]fc.up.pt / joaofgo[at]gmail.com)
##
## Script title: Compilation of Marxan data
##


dataDir<-"D:/MyDocs/MarxanResults"

##
# Simulation parameters | initial conditions
#
# SP 		Species only scenario
# SP_PA 	Species and Protected Areas
# SP_ST		Species and environmental stratification
# SP_PA_ST	Species, Protected Areas and environmental stratification
# Target number of species = [10, 20, 30, 40, 50]

scn<-c("SP","SP_PA","SP_ST","SP_ST_PA")
targets<-c(paste("T",seq(10,50,10),sep=""))
marxanData<-list()


for(target in targets){
	for(s in scn){
		cat(target,s," .... ",sep="|")
		tmpDataDF<-read.csv(paste(dataDir,"ids.csv",sep="/"),stringsAsFactors=FALSE)
		marxanFiles<-list.files(paste(dataDir,target,s,sep="/"),full.names=TRUE)
		
		for(f in marxanFiles){
			tmp<-read.table(f,sep=",",header=TRUE,stringsAsFactors=FALSE)
			tmpDataDF<-merge(tmpDataDF,tmp,by.x="UNIT_ID",by.y="planning_unit")
		}
		colnames(tmpDataDF)<-c("ID","UTM10K",paste(target,s,1:length(marxanFiles),sep="_"))
		marxanData[[target]][[s]]<-tmpDataDF
		cat("done.\n")
	}
}

save(marxanData,file="D:/MyDocs/MarxanResults/marxanCompiledData.RData")
