
##
## Supporting Information - R script for the manuscript paper entitled:
## "Systematic site selection for multi-species monitoring networks"
## Carvalho, S.[1], Gonalves, J.[1], Guisan, A.[2], Honrado, J.[1], 2015
## Journal Of Applied Ecology
## 
## [1] InBIO/CIBIO - Research Center in Biodiversity and Genetic Resources
## 	   Faculty of Sciences - University of Porto
## [2] University of Lausanne, Ecology and Evolution
## 
## Contacting author on this section: 
## Joo Gonalves (jfgoncalves[at]fc.up.pt / joaofgo[at]gmail.com)
##
## Script title: auxiliary functions for making boxplots with network sample sizes
## obtained from Marxan simulations 
##

# A boxplot to display sample sizes for all scenario/target combinations
# Boxplots display the variations of sample for all 100 replicates for a given
# scenario/target combination

replaceBy<-function(x, what, by,col){
	i<-0
	for(w in what){
		i<-i+1
		x[x[,col]==w,col]<-by[i]
	}
	return(x)
}

optimSamp.Nsamp<-as.data.frame(optimSamp.Nsamp)
optimSamp.Nsamp[,"NSamples"]<-as.integer(optimSamp.Nsamp[,"NSamples"])


# "SP"     		-> OPT_NS
# "SP_PA"  		-> OPT_PA
# "SP_ST"  		-> OPT_ENV
# "SP_ST_PA"	-> OPT_ENVPA

scn.old<-c("SP","SP_PA","SP_ST","SP_ST_PA")
scn.new<-c("OPT-NS", "OPT-PA", "OPT-ENV", "OPT-ENVPA")

#optimSamp.NSamples1<-replaceBy(optimSamp.NSamples,scn,scn.new,col="Scenario")
optimSamp.NSamples1<-replaceBy(optimSamp.Nsamp,scn.old,scn.new,col="Scenario")

optimSamp.NSamples1<-data.frame(optimSamp.NSamples1,orderBy=optimSamp.NSamples1[,"Scenario"])
optimSamp.NSamples1[,"orderBy"]<-as.character(optimSamp.NSamples1[,"orderBy"])

scn.order<-c(1, 2, 3, 4)
optimSamp.NSamples1<-replaceBy(optimSamp.NSamples1,scn.new,scn.order,col="orderBy")


# ----------------
# Boxplot
# ----------------


#png(file="D:/MyDocs/SampleSize_Boxplot.png",res=300,width=4000,height=3000)
png(file="D:/MyDocs/OptimMonitNetworks/SampleSize_WithCost_Boxplot.png",res=300,width=4000,height=3500)


par("mai"=c(1.5, 0.8, 0.8, 0.4))

boxplot(NSamples ~ orderBy + Target,boxwex=0.8,las=2,names=rep(scn.new[scn.order],5),
		main="Sample size",data=optimSamp.NSamples1,ylim=c(0,180),outline=FALSE)

for(j in c(4.5,8.5,12.5,16.5)) 
	abline(v=j,lty=3,col="black")

text(x=c(2.5,6.5,10.5,14.5,18.5),y=c(175),labels=targets)

dev.off()


# ----------------
# Median
# ----------------


png(file="D:/MyDocs/OptimMonitNetworks/SampleSizeOptimCost_Median_Barplot.png",res=300,width=4000,height=3000)

par("mai"=c(1.5, 0.8, 0.8, 0.4))

sampSize.MD <- aggregate(NSamples ~ Scenario + Target, median, data=optimSamp.NSamples1)
ind<-c(3,4,1,2); ind<-c(ind,ind+4,ind+8,ind+12,ind+16)

barplot(sampSize.MD[ind,"NSamples"],names=sampSize.MD[ind,"Scenario"],col=rep(colors()[c(250,230,210,190,170)]
,each=4),las=2,ylim=c(0,200),main="Median sample size")

legend("topleft",legend=paste("T",seq(10,50,10),sep=""),fill=colors()[c(250,230,210,190,170)],bty="n")

box()
dev.off()

# ----------------
# Mean
# ----------------

png(file="D:/MyDocs/OptimMonitNetworks/SampleSizeOptimCost_Mean_Barplot.png",res=300,width=4000,height=3000)

par("mai"=c(1.5, 0.8, 0.8, 0.4))

sampSize.MN <- aggregate(NSamples ~ Scenario + Target, mean, data=optimSamp.NSamples1)
ind<-c(3,4,1,2); ind<-c(ind,ind+4,ind+8,ind+12,ind+16)

barplot(sampSize.MN[ind,"NSamples"],names=sampSize.MN[ind,"Scenario"],col=rep(colors()[c(250,230,210,190,170)]
				,each=4),las=2,ylim=c(0,200),main="Average sample size")

legend("topleft",legend=paste("T",seq(10,50,10),sep=""),fill=colors()[c(250,230,210,190,170)],bty="n")

box()
dev.off()


write.csv(sampSize.MD,file="D:/MyDocs/OptimMonitNetworks/Median_OptimCost_SampSize.csv")
write.csv(sampSize.MN,file="D:/MyDocs/OptimMonitNetworks/Mean_OptimCost_SampSize.csv")
write.csv(optimSamp.NSamples1,file="D:/MyDocs/OptimMonitNetworks/SampSize_OptimCost_AllRounds.csv")

