
##
## Supporting Information - R script for the manuscript paper entitled:
## "Systematic site selection for multi-species monitoring networks"
## Carvalho, S.[1], Gonalves, J.[1], Guisan, A.[2], Honrado, J.[1], 2015
## Journal Of Applied Ecology
## 
## [1] InBIO/CIBIO - Research Center in Biodiversity and Genetic Resources
## 	   Faculty of Sciences - University of Porto
## [2] University of Lausanne, Ecology and Evolution
## 
## Contacting author on this section: 
## Joo Gonalves (jfgoncalves[at]fc.up.pt / joaofgo[at]gmail.com)
##
## Script title: calculate statistics for species based on optimized and
## non-optimized network simulations
##


## Define some parameters and data specifications
##
require(vegan)

ID<-"ID" 							# Column with row IDs (MGRS codes)
UID<-"UNIT_ID" 						# Column with unique row IDs
SpCols<-7:51						# Species occurence/distribution by 10km quadrats
SpNames<-colnames(dataDF)[SpCols]
rid<-1:nrow(dataDF) 				# Row integer ids (for sampling purposes)
nRep<-100							# Number of replicates

## Pseudo-real prevalence
np_i<-apply(dataDF[,SpCols],2,sum)
#na_i<-nrow(dataDF)-np_i
#prev_i<-np_i/na_i
prev_i<-np_i/nrow(dataDF)

## Scenarios and targets
scn<-c("SP","SP_PA","SP_ST","SP_ST_PA")
targets<-c(paste("T",seq(10,50,10),sep=""))
targNum<-seq(10,50,10)
names(targNum)<-targets
verbose<-TRUE


combs<-expand.grid(scn,targets)
combs<-cbind(combs,Var3=paste(combs[,1],combs[,2],sep="_"))

#statsPerSp.MN<-matrix(nrow=length(SpCols),ncol=length(scn)*length(targets)*2,
#		dimnames=list(SpNames,paste(c("OPS","NOS"),rep(combs[,3],each=2),sep="_")))
#
#statsPerSp.Prob<-matrix(nrow=length(SpCols),ncol=length(scn)*length(targets)*2,
#		dimnames=list(SpNames,paste(c("OPS","NOS"),rep(combs[,3],each=2),sep="_")))
#
#statsPerSp.MNdiff<-matrix(nrow=length(SpCols),ncol=length(scn)*length(targets),
#		dimnames=list(SpNames,combs[,3]))

statsPerSp.PrevDiff<-matrix(nrow=length(SpCols),ncol=length(scn)*length(targets),
		dimnames=list(SpNames,combs[,3]))


for(s in scn){
	for(target in targets){

		#statsPerSp.MN[,paste("OPS",s,target,sep="_")]<-apply(optimSamp.NPPS[[s]][[target]],2,mean) / 1000
		#statsPerSp.MN[,paste("NOS",s,target,sep="_")]<-apply(nonOptimSamp.NPPS[[s]][[target]],2,mean) / 997
		
		# Accounts for prevalence
		#statsPerSp.MNdiff[,paste(s,target,sep="_")]<-(apply(optimSamp.NPPS[[s]][[target]],2,mean)-apply(nonOptimSamp.NPPS[[s]][[target]],2,mean))/np_i
		
		# Calculate the probability of sampling p' = #count / nrep
		#statsPerSp.Prob[,paste("OPS",s,target,sep="_")]<-apply(optimSamp.NPPS[[s]][[target]],2,countIf)/nrow()
		#statsPerSp.Prob[,paste("NOS",s,target,sep="_")]<-apply(nonOptimSamp.NPPS[[s]][[target]],2,countIf)
		
		# Calculate the differences in prevalence for OPS and NOS for each scn/tgt
		nSamp<-as.integer(optimSamp.Nsamp[(optimSamp.Nsamp[,"Scenario"]==s & optimSamp.Nsamp[,"Target"]==target),"NSamples"])
		
		mn.prev.ops<-apply(optimSamp.NPPS[[s]][[target]]/nSamp,2,mean)
		mn.prev.nos<-apply(nonOptimSamp.NPPS[[s]][[target]]/nSamp,2,mean)
		
		statsPerSp.PrevDiff[,paste(s,target,sep="_")]<-mn.prev.ops-mn.prev.nos

	}
}

## Make biplot relating Pi to Di
png(file="D:/MyDocs/temp/prev_diff_ops_nos.png",2000,2000,res=300)
par(mar=c(5,6,3,1))
plot(prev_diff~prev_i,data=tmp.df,xlab="Species predicted prevalence (Pi)", type="n",cex=1.2,cex.axis=1.2,cex.lab=1.2,
     ylab="Mean difference in species monitoring prevalence\n between optimized and non-optimized networks (Di)")

abline(h=0,lty=2,col="grey")
points(tmp.df[,2],tmp.df[,1])

# Linear model | Di ~ pseudo-real-prevalence 
lm.prev<-lm(prev_diff~prev_i,data=tmp.df)
plt.ord<-order(tmp.df[,"prev_i"])
pred.prev<-predict(lm.prev,interval="confidence")
lines(tmp.df[plt.ord,"prev_i"],pred.prev[plt.ord,"fit"],lwd=2,col="black")
lines(tmp.df[plt.ord,"prev_i"],pred.prev[plt.ord,"lwr"],lty=2)
lines(tmp.df[plt.ord,"prev_i"],pred.prev[plt.ord,"upr"],lty=2)

dev.off()



